@@ -190,7 +190,7 @@ class DFReader(object):
         if self.px4_timestamps:
             m._timestamp = self.timebase + self.px4_timebase
         elif self.new_timestamps:
-            if m.get_type() == 'GPS':
+            if m.get_type() in ['GPS','GPS2']:
                 m._timestamp = self.timebase + m.T*0.001
             elif 'TimeMS' in m._fieldnames:
                 m._timestamp = self.timebase + m.TimeMS*0.001
@@ -220,6 +220,7 @@ class DFReader(object):
 
         if type == 'TIME' and 'StartTime' in m._fieldnames:
             self.px4_timebase = m.StartTime * 1.0e-6
+            self.px4_timestamps = True
         if type == 'GPS':
             self._adjust_time_base(m)
         if type == 'MODE':
@@ -334,6 +335,7 @@ class DFReader_text(DFReader):
         }
         self._rewind()
         self._find_time_base()
+        self._rewind()
 
     def _rewind(self):
         '''rewind to start of log'''
